Tournament Watford, England July 28th 2001 ?? players https://groups.google.com/d/msg/rec.games.trading-cards.jyhad/71LhwjAs4gU/dE6tNWdJgrcJ -- 7vp in the final Tony Smith Deck: Notaweeniedominatedeck version III The idea is to hit the ground running. Either use superior govern to pull out your vamps for 1 pool, and assault once a huge force is amassed. Or bleed like shit off a shovel from the first turn. Either way it often takes out multiply preys in a turn. If it's running well, and your prey has no deflections, it should clean then out in about 4 turns. Little combat defense but letting a few die to get through with the one 6 point bleed is often the way to go Cheesy as hell, but funny as fuck. Ivory Bow (didn't see it all day, may need to come out) The 2 vamps in the crypt with superior dominate were a last minute thing. They can't use the governs at superior, but the inclusion allowed me to cut the number of dom masters and makes it run a little quicker if they are in the opening crypt. I found that by using 4 caps as opposed to the normal dom weenies, I got all the benefits of a weenie deck, but with a few less disadvantages. Crypt (13 cards, min=16, max=18, avg=4.15) ------------------------------------------ 1x Aleph 4 AUS dom Malkavian:1 1x Courtland Leighton 4 dom for pre Ventrue:1 1x Francesca Giovanni 4 dom nec pot Giovanni:2 1x Gloria Giovanni 4 DOM nec Giovanni:2 1x Ignacio, The Black Priest 4 dom obt pot Lasombra:2 1x Ignatius 4 aus dom tha Tremere:1 1x Ingrid Russo 4 DOM for Ventrue antitribu:2 1x Laurent de Valois 4 ani dom obf Nosferatu:2 1x Peter Blaine 4 aus dom for Ventrue antitribu:2 1x Roland Bishop 4 aus dom obf Malkavian:1 1x Sarah Cobbler 4 THA dom Tremere:1 1x Violette Prentiss 4 PRE dom Ventrue:1 1x Tony 6 AUS DEM dom obf Malkavian:3 Library (87 cards) Master (21) 5x Blood Doll 7x Dominate 2x Dreams of the Sphinx 4x Effective Management 2x Hostile Takeover -- I know that there are only 2 ventru in the crypt but trust me, the hostiles have won games for me more than once 1x Sudden Reversal Action (10) 10x Govern the Unaligned Equipment (1) 1x Ivory Bow -- didn't see it all day, may need to come out Action Modifier (32) 6x Bonding 4x Change of Target 6x Conditioning 10x Seduction -- the numbers of both of these has fluctuated between 8 and 12. for this tourney I went for the happy medium. 2x Sleeping Mind, The 4x Threats Reaction (15) 7x Deflection -- undoubtedly saved me in the final 3x Delaying Tactics -- one more is probably necessary 5x Wake with Evening's Freshness -- changed from 4 at the last minute Combat (8) 3x Dodge 5x Fake Out